#include <bits/stdc++.h>

using namespace std;

/**
    Problem        : Chimichangas
    Algorithm      : brute-force polynomial multiplication + particular test (Subtask 2)
    Expected score : 50p
    Author         : Alexandru Valeanu
**/

const int MOD = 2999;
const int MAX_N = 100000 + 1;

struct Polynomial
{
    int coef[MAX_N];
    int degree;

    void clear()
    {
        for (int i = 0; i <= this->degree; ++i)
            this->coef[i] = 0;
    }

    Polynomial& operator = (const Polynomial &P)
    {
        this->degree = P.degree;

        for (int i = 0; i <= this->degree; ++i)
            this->coef[i] = P.coef[i];

        return *this;
    }
};

void multiply(const Polynomial &A, const Polynomial &B, Polynomial &C)
{
    C.degree = A.degree + B.degree;
    C.clear();

    for (int i = 0; i <= A.degree; ++i)
        for (int j = 0; j <= B.degree; ++j)
        {
            int s = (A.coef[i] * B.coef[j]) % MOD;

            C.coef[i + j] = C.coef[i + j] + s;

            if (C.coef[i + j] >= MOD)
                C.coef[i + j] -= MOD;
        }
}

void power(Polynomial &P, int exponent)
{
    assert(exponent > 0);
    exponent--;

    Polynomial SOL = P;
    Polynomial A = P;
    Polynomial tmp;

    while (exponent > 0)
    {
        if (exponent & 1)
        {
            multiply(SOL, A, tmp);
            SOL = tmp;
        }

        multiply(A, A, tmp);
        A = tmp;

        exponent >>= 1;
    }

    P = SOL;
}

int main()
{
    ifstream in("chimichangas.in");
    ofstream out("chimichangas.out");

    int N, K;
    int Q;

    assert(in >> N >> K);

    int maxC = 0;
    vector<int> calory;

    for (int i = 0; i < N; ++i)
    {
        int x;
        assert(in >> x);

        calory.push_back(x);
    }

    in >> Q;

    if (K == 2 && Q <= 100)
    {
        set<int> seen;

        for (int i = 0; i < N; ++i)
            seen.insert(calory[i]);

        while (Q--)
        {
            int weight;
            in >> weight;

            int sol = 0;

            for (int i = 0; i < N; ++i)
            {
                if (seen.find(weight - calory[i]) != seen.end())
                    sol++;
            }

            out << sol % MOD << "\n";
        }

        return 0;
    }

    maxC = *max_element(calory.begin(), calory.end());

    Polynomial P;
    P.clear();
    P.degree = maxC;

    for (int i = 0; i < N; ++i)
        P.coef[ calory[i] ] = 1;

    power(P, K);
    assert(P.degree == maxC * K);

    while (Q--)
    {
        int weight;
        assert(in >> weight);

        if (weight > maxC * K)
            out << 0 << "\n";
        else
            out << P.coef[weight] << "\n";
    }

    return 0;
}
