/**
 * Method: compute A^k = (x^calorie_1 + ... + x^calorie_n)^k naively.
 * The answer for a target of meal_i is the coefficient of x^meal_i in A^k.
 **/
#include <stdio.h>
#include <string.h>

#define MAX_DIGITS 100000
#define MODULO 2999

typedef struct {
  int n;
  long long d[MAX_DIGITS + 1];
} huge;

void printPoly(huge *h) {
  int i;

  for (i = h->n - 1; i >= 0; i--) {
    if (h->d[i]) {
      printf("%lld * x^%d + ", h->d[i], i);
    }
  }
  printf("\n");
}

/* C <-- A * B */
void mult(huge *a, huge *b, huge *c) {
  int i, j;

  memset(c, 0, sizeof(*c));
  c->n = a->n + b->n;

  for (i = 0; i < a->n; i++) {
    for (j = 0; j < b->n; j++) {
      c->d[i + j] += a->d[i] * b->d[j];
    }
  }

  for (i = 0; i < c->n; i++) {
    c->d[i] %= MODULO;
  }

  while (!c->d[c->n - 1]) {
    c->n--;
  }
}

int main(void) {
  int n, k, x, q;
  huge a, p, tmp;

  FILE *fin = fopen("chimichangas.in", "r");
  FILE *fout = fopen("chimichangas.out", "w");
  fscanf(fin, "%d%d", &n, &k);

  /* Construct p = A^1 */
  memset(&p, 0, sizeof(p));
  while (n--) {
    fscanf(fin, "%d", &x);
    p.d[x] = 1;
    if (x + 1 > p.n) {
      p.n = x + 1;
    }
  }

  /* Compute A^k */
  a.n = 1;
  a.d[0] = 1;
  while (k) {
    if (k & 1) {
      mult(&a, &p, &tmp);
      a = tmp;
    }
    k >>= 1;
    if (k) {
      mult(&p, &p, &tmp);
      p = tmp;
    }
  }

  fscanf(fin, "%d", &q);
  while (q--) {
    fscanf(fin, "%d", &x);
    fprintf(fout, "%lld\n", (x >= a.n) ? 0 : a.d[x]);
  }

  fclose(fin);
  fclose(fout);

  return 0;
}
